==> imgly_sdk-1.0.0.tar.gz: README.md <==
<p align="center">
  <a href="https://img.ly/?utm_campaign=Projects&utm_source=Github&utm_medium=IMGLY&utm_content=Flutter"">
    <img src="https://uploads-ssl.webflow.com/5f7574bdf1696c4b4bf518ea/5f75b58e3a7013e64675400c_IMG_LY.svg" alt="IMG.LY Logo"/>
  </a>
</p>
<p align="center">
  <a href="https://pub.dev/packages/imgly_sdk">
    <img src="https://img.shields.io/pub/v/imgly_sdk?color=blue" alt="pub.dev version">
  </a>
  <a href="https://pub.dev/packages/imgly_sdk">
    <img src="https://img.shields.io/badge/platforms-android%20|%20ios-lightgrey.svg" alt="Platform support">
  </a>
  <a href="https://twitter.com/imgly">
    <img src="https://img.shields.io/badge/twitter-@imgly-blue.svg?style=flat" alt="Twitter">
  </a>
</p>

# Flutter plugin for IMG.LY SDK

**:warning: This library is automatically integrated when adding the plugin packages `photoeditor_sdk` and/or `videoeditor_sdk` as a dependency. Do NOT integrate `imgly_sdk` manually!**

A plugin containing the shared resources for [`photoeditor_sdk`](https://pub.dev/packages/photoeditor_sdk) and [`videoeditor_sdk`](https://pub.dev/packages/videoeditor_sdk).

## License Terms

Make sure you have a [commercial license](https://account.photoeditorsdk.com/pricing?utm_campaign=Projects&utm_source=Github&utm_medium=IMGLY&utm_content=Flutter) for PhotoEditor SDK and/or VideoEditor SDK before releasing your app.
A commercial license is required for any app or service that has any form of monetization: This includes free apps with in-app purchases or ad supported applications. Please contact us if you want to purchase the commercial license.

## Support and License

Use our [service desk](http://support.photoeditorsdk.com) for bug reports or support requests. To request a commercial license, please use the [license request form](https://account.photoeditorsdk.com/pricing?utm_campaign=Projects&utm_source=Github&utm_medium=IMGLY&utm_content=Flutter) on our website.

==> imgly_sdk-1.0.1.tar.gz: README.md <==
<p align="center">
  <a href="https://img.ly/?utm_campaign=Projects&utm_source=Github&utm_medium=IMGLY&utm_content=Flutter"">
    <img src="https://uploads-ssl.webflow.com/5f7574bdf1696c4b4bf518ea/5f75b58e3a7013e64675400c_IMG_LY.svg" alt="IMG.LY Logo"/>
  </a>
</p>
<p align="center">
  <a href="https://pub.dev/packages/imgly_sdk">
    <img src="https://img.shields.io/pub/v/imgly_sdk?color=blue" alt="pub.dev version">
  </a>
  <a href="https://pub.dev/packages/imgly_sdk">
    <img src="https://img.shields.io/badge/platforms-android%20|%20ios-lightgrey.svg" alt="Platform support">
  </a>
  <a href="https://twitter.com/imgly">
    <img src="https://img.shields.io/badge/twitter-@imgly-blue.svg?style=flat" alt="Twitter">
  </a>
</p>

# Flutter plugin for IMG.LY SDK

**⚠️ This library is automatically integrated when adding the plugin packages `photo_editor_sdk` and/or `video_editor_sdk` as a dependency. Do NOT integrate `imgly_sdk` manually!**

A plugin containing the shared resources for [`photo_editor_sdk`](https://pub.dev/packages/photo_editor_sdk) and [`video_editor_sdk`](https://pub.dev/packages/video_editor_sdk).

## License Terms

Make sure you have a [commercial license](https://account.photoeditorsdk.com/pricing?utm_campaign=Projects&utm_source=Github&utm_medium=IMGLY&utm_content=Flutter) for PhotoEditor SDK and/or VideoEditor SDK before releasing your app.
A commercial license is required for any app or service that has any form of monetization: This includes free apps with in-app purchases or ad supported applications. Please contact us if you want to purchase the commercial license.

## Support and License

Use our [service desk](https://support.photoeditorsdk.com) for bug reports or support requests. To request a commercial license, please use the [license request form](https://account.photoeditorsdk.com/pricing?utm_campaign=Projects&utm_source=Github&utm_medium=IMGLY&utm_content=Flutter) on our website.
